betty.test_utils.ancestry.date - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
Toggle table of contents sidebar

# Source code for betty.test_utils.ancestry.date

    """
    Test utilities for :py:mod:`betty.ancestry.date`.
    """

    from betty.ancestry.date import HasDate

    class DummyHasDate(HasDate):
        """
        A dummy :py:class:`betty.ancestry.date.HasDate` implementation.
        """

        pass